# What's Changed

> **这是 v4.0.0 的测试版本（beta.1），功能尚未完全稳定和加入**。v4.0.0 被设计为向前兼容，如有任何插件兼容性问题或者其他异常请在 GitHub 提交 [Issue](https://github.com/AstrBotDevs/AstrBot/issues)。在测试版本期间，您可以无缝回退到旧版本的 AstrBot，并且数据不受影响。
